// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `DCMI Metadata Terms - other` vocabulary
//!
//! This module requires `ns-dcterms` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|DCMI Metadata Terms - other|
//! |**Prefix**|dcterms|
//! |**Namespace base IRI**|<http://purl.org/dc/terms/>|
//! |**Description**||
//! |**Is defined by**|<http://purl.org/dc/terms/>|
//!

use crate::namespace;

namespace!(
    "http://purl.org/dc/terms/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Agent`: A resource that acts or has the power to act.
    Agent, "Agent",
    /// `Agent Class`: A group of agents.
    AgentClass, "AgentClass",
    /// `Bibliographic Resource`: A book, article, or other documentary resource.
    BibliographicResource, "BibliographicResource",
    /// `DCMI Box`: The set of regions in space defined by their geographic coordinates according to the DCMI Box Encoding Scheme.
    Box, "Box",
    /// `DCMI Type Vocabulary`: The set of classes specified by the DCMI Type Vocabulary, used to categorize the nature or genre of the resource.
    DCMIType, "DCMIType",
    /// `DDC`: The set of conceptual resources specified by the Dewey Decimal Classification.
    DDC, "DDC",
    /// `Extent`: 
    Extent, "Extent",
    /// `File Format`: A digital resource format.
    FileFormat, "FileFormat",
    /// `Frequency`: A rate at which something recurs.
    Frequency, "Frequency",
    /// `IMT`: The set of media types specified by the Internet Assigned Numbers Authority.
    IMT, "IMT",
    /// `ISO 3166`: The set of codes listed in ISO 3166-1 for the representation of names of countries.
    ISO3166, "ISO3166",
    /// `ISO 639-2`: The three-letter alphabetic codes listed in ISO639-2 for the representation of names of languages.
    ISO639_2, "ISO639-2",
    /// `ISO 639-3`: The set of three-letter codes listed in ISO 639-3 for the representation of names of languages.
    ISO639_3, "ISO639-3",
    /// `Jurisdiction`: The extent or range of judicial, law enforcement, or other authority.
    Jurisdiction, "Jurisdiction",
    /// `LCC`: The set of conceptual resources specified by the Library of Congress Classification.
    LCC, "LCC",
    /// `LCSH`: The set of labeled concepts specified by the Library of Congress Subject Headings.
    LCSH, "LCSH",
    /// `License Document`: A legal document giving official permission to do something with a resource.
    LicenseDocument, "LicenseDocument",
    /// `Linguistic System`: A system of signs, symbols, sounds, gestures, or rules used in communication.
    LinguisticSystem, "LinguisticSystem",
    /// `Location`: A spatial region or named place.
    Location, "Location",
    /// `Location, Period, or Jurisdiction`: A location, period of time, or jurisdiction.
    LocationPeriodOrJurisdiction, "LocationPeriodOrJurisdiction",
    /// `MeSH`: The set of labeled concepts specified by the Medical Subject Headings.
    MESH, "MESH",
    /// `Media Type`: A file format or physical medium.
    MediaType, "MediaType",
    /// `Media Type or Extent`: A media type or extent.
    MediaTypeOrExtent, "MediaTypeOrExtent",
    /// `Method of Accrual`: A method by which resources are added to a collection.
    MethodOfAccrual, "MethodOfAccrual",
    /// `Method of Instruction`: A process that is used to engender knowledge, attitudes, and skills.
    MethodOfInstruction, "MethodOfInstruction",
    /// `NLM`: The set of conceptual resources specified by the National Library of Medicine Classification.
    NLM, "NLM",
    /// `DCMI Period`: The set of time intervals defined by their limits according to the DCMI Period Encoding Scheme.
    Period, "Period",
    /// `Period of Time`: An interval of time that is named or defined by its start and end dates.
    PeriodOfTime, "PeriodOfTime",
    /// `Physical Medium`: A physical material or carrier.
    PhysicalMedium, "PhysicalMedium",
    /// `Physical Resource`: A material thing.
    PhysicalResource, "PhysicalResource",
    /// `DCMI Point`: The set of points in space defined by their geographic coordinates according to the DCMI Point Encoding Scheme.
    Point, "Point",
    /// `Policy`: A plan or course of action by an authority, intended to influence and determine decisions, actions, and other matters.
    Policy, "Policy",
    /// `Provenance Statement`: Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.
    ProvenanceStatement, "ProvenanceStatement",
    /// `RFC 1766`: The set of tags, constructed according to RFC 1766, for the identification of languages.
    RFC1766, "RFC1766",
    /// `RFC 3066`: The set of tags constructed according to RFC 3066 for the identification of languages.
    RFC3066, "RFC3066",
    /// `RFC 4646`: The set of tags constructed according to RFC 4646 for the identification of languages.
    RFC4646, "RFC4646",
    /// `RFC 5646`: The set of tags constructed according to RFC 5646 for the identification of languages.
    RFC5646, "RFC5646",
    /// `Rights Statement`: A statement about the intellectual property rights (IPR) held in or over a resource, a legal document giving official permission to do something with a resource, or a statement about access rights.
    RightsStatement, "RightsStatement",
    /// `Size or Duration`: A dimension or extent, or a time taken to play or execute.
    SizeOrDuration, "SizeOrDuration",
    /// `Standard`: A reference point against which other things can be evaluated or compared.
    Standard, "Standard",
    /// `TGN`: The set of places specified by the Getty Thesaurus of Geographic Names.
    TGN, "TGN",
    /// `UDC`: The set of conceptual resources specified by the Universal Decimal Classification.
    UDC, "UDC",
    /// `URI`: The set of identifiers constructed according to the generic syntax for Uniform Resource Identifiers as specified by the Internet Engineering Task Force.
    URI, "URI",
    /// `W3C-DTF`: The set of dates and times constructed according to the W3C Date and Time Formats Specification.
    W3CDTF, "W3CDTF",
    /// `Abstract`: A summary of the resource.
    abstract_, "abstract",
    /// `Access Rights`: Information about who access the resource or an indication of its security status.
    accessRights, "accessRights",
    /// `Accrual Method`: The method by which items are added to a collection.
    accrualMethod, "accrualMethod",
    /// `Accrual Periodicity`: The frequency with which items are added to a collection.
    accrualPeriodicity, "accrualPeriodicity",
    /// `Accrual Policy`: The policy governing the addition of items to a collection.
    accrualPolicy, "accrualPolicy",
    /// `Alternative Title`: An alternative name for the resource.
    alternative, "alternative",
    /// `Audience`: A class of agents for whom the resource is intended or useful.
    audience, "audience",
    /// `Date Available`: Date that the resource became or will become available.
    available, "available",
    /// `Bibliographic Citation`: A bibliographic reference for the resource.
    bibliographicCitation, "bibliographicCitation",
    /// `Conforms To`: An established standard to which the described resource conforms.
    conformsTo, "conformsTo",
    /// `Contributor`: An entity responsible for making contributions to the resource.
    contributor, "contributor",
    /// `Coverage`: The spatial or temporal topic of the resource, spatial applicability of the resource, or jurisdiction under which the resource is relevant.
    coverage, "coverage",
    /// `Date Created`: Date of creation of the resource.
    created, "created",
    /// `Creator`: An entity responsible for making the resource.
    creator, "creator",
    /// `Date`: A point or period of time associated with an event in the lifecycle of the resource.
    date, "date",
    /// `Date Accepted`: Date of acceptance of the resource.
    dateAccepted, "dateAccepted",
    /// `Date Copyrighted`: Date of copyright of the resource.
    dateCopyrighted, "dateCopyrighted",
    /// `Date Submitted`: Date of submission of the resource.
    dateSubmitted, "dateSubmitted",
    /// `Description`: An account of the resource.
    description, "description",
    /// `Audience Education Level`: A class of agents, defined in terms of progression through an educational or training context, for which the described resource is intended.
    educationLevel, "educationLevel",
    /// `Extent`: The size or duration of the resource.
    extent, "extent",
    /// `Format`: The file format, physical medium, or dimensions of the resource.
    format, "format",
    /// `Has Format`: A related resource that is substantially the same as the pre-existing described resource, but in another format.
    hasFormat, "hasFormat",
    /// `Has Part`: A related resource that is included either physically or logically in the described resource.
    hasPart, "hasPart",
    /// `Has Version`: A related resource that is a version, edition, or adaptation of the described resource.
    hasVersion, "hasVersion",
    /// `Identifier`: An unambiguous reference to the resource within a given context.
    identifier, "identifier",
    /// `Instructional Method`: A process, used to engender knowledge, attitudes and skills, that the described resource is designed to support.
    instructionalMethod, "instructionalMethod",
    /// `Is Format Of`: A pre-existing related resource that is substantially the same as the described resource, but in another format.
    isFormatOf, "isFormatOf",
    /// `Is Part Of`: A related resource in which the described resource is physically or logically included.
    isPartOf, "isPartOf",
    /// `Is Referenced By`: A related resource that references, cites, or otherwise points to the described resource.
    isReferencedBy, "isReferencedBy",
    /// `Is Replaced By`: A related resource that supplants, displaces, or supersedes the described resource.
    isReplacedBy, "isReplacedBy",
    /// `Is Required By`: A related resource that requires the described resource to support its function, delivery, or coherence.
    isRequiredBy, "isRequiredBy",
    /// `Is Version Of`: A related resource of which the described resource is a version, edition, or adaptation.
    isVersionOf, "isVersionOf",
    /// `Date Issued`: Date of formal issuance of the resource.
    issued, "issued",
    /// `Language`: A language of the resource.
    language, "language",
    /// `License`: A legal document giving official permission to do something with the resource.
    license, "license",
    /// `Mediator`: An entity that mediates access to the resource.
    mediator, "mediator",
    /// `Medium`: The material or physical carrier of the resource.
    medium, "medium",
    /// `Date Modified`: Date on which the resource was changed.
    modified, "modified",
    /// `Provenance`: A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation.
    provenance, "provenance",
    /// `Publisher`: An entity responsible for making the resource available.
    publisher, "publisher",
    /// `References`: A related resource that is referenced, cited, or otherwise pointed to by the described resource.
    references, "references",
    /// `Relation`: A related resource.
    relation, "relation",
    /// `Replaces`: A related resource that is supplanted, displaced, or superseded by the described resource.
    replaces, "replaces",
    /// `Requires`: A related resource that is required by the described resource to support its function, delivery, or coherence.
    requires, "requires",
    /// `Rights`: Information about rights held in and over the resource.
    rights, "rights",
    /// `Rights Holder`: A person or organization owning or managing rights over the resource.
    rightsHolder, "rightsHolder",
    /// `Source`: A related resource from which the described resource is derived.
    source, "source",
    /// `Spatial Coverage`: Spatial characteristics of the resource.
    spatial, "spatial",
    /// `Subject`: A topic of the resource.
    subject, "subject",
    /// `Table Of Contents`: A list of subunits of the resource.
    tableOfContents, "tableOfContents",
    /// `Temporal Coverage`: Temporal characteristics of the resource.
    temporal, "temporal",
    /// `Title`: A name given to the resource.
    title, "title",
    /// `Type`: The nature or genre of the resource.
    type_, "type",
    /// `Date Valid`: Date (often a range) of validity of a resource.
    valid, "valid"
);
